@@ -14,11 +14,11 @@ URI::geo - The geo URI scheme.
 
 =head1 VERSION
 
-This document describes URI::geo version 0.02
+This document describes URI::geo version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -58,13 +58,9 @@ From L<http://geouri.org/>:
   }
 }
 
-=for internal
-
-Try hard to extract location information from something. We handle lat,
-lon, alt as scalars, arrays containing lat, lon, alt, hashes with
-suitably named keys and objects with suitably named methods.
-
-=cut
+# Try hard to extract location information from something. We handle lat,
+# lon, alt as scalars, arrays containing lat, lon, alt, hashes with
+# suitably named keys and objects with suitably named methods.
 
 sub _location_of_pointy_thing {
   my $class = shift;
@@ -166,7 +162,7 @@ Create a new URI::geo. The arguments should be either
 
 =item * a reference to an array containing lat, lon, alt
 
-=item * a reference to a hash with suitably named keys
+=item * a reference to a hash with suitably named keys or
 
 =item * a reference to an object with suitably named accessors
 
@@ -182,7 +178,28 @@ accessors called C<lat>, C<latitude>, C<lon>, C<long>, C<longitude>,
 C<ele>, C<alt>, C<elevation> or C<altitude> and use them.
 
 Often if you have an object or hash reference that represents a point
-you can pass it directly to C<new>.
+you can pass it directly to C<new>; so for example this will work:
+
+  use URI::geo;
+  use Geo::Point;
+
+  my $pt = Geo::Point->latlong( 48.208333, 16.372778 );
+  my $guri = URI::geo->new( $pt );
+
+As will this:
+
+  my $guri = URI::geo->new( { lat => 55, lon => -1 } );
+
+and this:
+
+  my $guri = URI::geo->new( 55, -1 );
+
+Note that you can also create a new C<GEO::uri> by passing a GeoURI to
+C<URI::new>:
+
+  use URI;
+
+  my $guri = URI->new( 'geo:55,-1' );
 
 =cut
 
@@ -198,6 +215,7 @@ sub _init {
 
   my $self = $class->SUPER::_init( $uri, $scheme );
 
+  # Normalise at poles.
   my $lat = $self->latitude;
   $self->longitude( 0 ) if $lat == 90 || $lat == -90;
   return $self;
@@ -220,8 +238,10 @@ sub location {
 
   my ( $scheme, $auth, $path, $query, $frag ) = uri_split $$self;
 
-  $$self = uri_join 'geo', $auth, $self->_path( @_ ), $query, $frag
-   if @_;
+  if ( @_ ) {
+    $path = $self->_path( @_ );
+    $$self = uri_join 'geo', $auth, $path, $query, $frag;
+  }
 
   return $self->_parse( $path );
 }
